"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Bucket = void 0;
const event_emitter_1 = require("@figliolia/event-emitter");
/**
 * Bucket
 *
 * A bucket is a wrapper around the native Map that
 * assigns an auto-incrementing ID to each value
 * added to the bucket. It provided a Queue-like
 * interface with the ability to access and remove
 * items in 0(1) time
 */
class Bucket {
    constructor() {
        this.bucket = new Map();
        this.IDs = new event_emitter_1.AutoIncrementingID();
    }
    /**
     * Enqueue
     *
     * Adds an item to the bucket and returns it's
     * unique ID
     */
    enqueue(item) {
        const ID = this.IDs.get();
        this.bucket.set(ID, item);
        return ID;
    }
    /**
     * Dequeue
     *
     * Removes the first item from the Bucket and
     * returns it
     */
    dequeue() {
        for (const [ID, item] of this.bucket) {
            this.bucket.delete(ID);
            return item;
        }
    }
    /**
     * peek
     *
     * Returns the first item from the Bucket or undefined
     * if the bucket is empty
     */
    peek() {
        for (const entry of this.bucket) {
            return entry;
        }
    }
    /**
     * Delete
     *
     * Removes an item from the bucket by ID
     */
    delete(ID) {
        return this.bucket.delete(ID);
    }
    /**
     * Clear
     *
     * Removes all items from the bucket
     */
    clear() {
        return this.bucket.clear();
    }
    /**
     * Is Empty
     *
     * Returns true if the bucket contains no items
     */
    get isEmpty() {
        return this.bucket.size === 0;
    }
    /**
     * Length
     *
     * Returns the total number of items in the bucket
     */
    get length() {
        return this.bucket.size;
    }
}
exports.Bucket = Bucket;
