import type { Queue } from "./types";
/**
 * Bucket
 *
 * A bucket is a wrapper around the native Map that
 * assigns an auto-incrementing ID to each value
 * added to the bucket. It provided a Queue-like
 * interface with the ability to access and remove
 * items in 0(1) time
 */
export declare class Bucket<T> implements Queue<T> {
    bucket: Map<string, T>;
    private IDs;
    /**
     * Enqueue
     *
     * Adds an item to the bucket and returns it's
     * unique ID
     */
    enqueue(item: T): string;
    /**
     * Dequeue
     *
     * Removes the first item from the Bucket and
     * returns it
     */
    dequeue(): T | undefined;
    /**
     * peek
     *
     * Returns the first item from the Bucket or undefined
     * if the bucket is empty
     */
    peek(): [string, T] | undefined;
    /**
     * Delete
     *
     * Removes an item from the bucket by ID
     */
    delete(ID: string): boolean;
    /**
     * Clear
     *
     * Removes all items from the bucket
     */
    clear(): void;
    /**
     * Is Empty
     *
     * Returns true if the bucket contains no items
     */
    get isEmpty(): boolean;
    /**
     * Length
     *
     * Returns the total number of items in the bucket
     */
    get length(): number;
}
